import { dataSource } from "../../../data-source";
import { mission } from "../../../entity/operation/mission";
import DatabaseActionException from "../../../exceptions/databaseActionException";
import { DeleteMissionCommand, UpdateMissionCommand } from "./missionCommand";

export default abstract class MissionCommandHandler {
  /**
   * @description create mission
   * @returns {Promise<string>}
   */
  static async create(): Promise<string> {
    return await dataSource
      .createQueryBuilder()
      .insert()
      .into(mission)
      .values({
        title: "",
      })
      .execute()
      .then((result) => {
        return result.identifiers[0].id;
      })
      .catch((err) => {
        throw new DatabaseActionException("CREATE", "mission", err);
      });
  }

  /**
   * @description update mission
   * @param {UpdateMissionCommand} updateMission
   * @returns {Promise<void>}
   */
  static async update(updateMission: UpdateMissionCommand): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .update(mission)
      .set({
        title: updateMission.title,
        keyword: updateMission.keyword,
      })
      .where("id = :id", { id: updateMission.id })
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("UPDATE", "mission", err);
      });
  }

  /**
   * @description delete mission
   * @param {DeleteMissionCommand} deleteMission
   * @returns {Promise<void>}
   */
  static async delete(deleteMission: DeleteMissionCommand): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .delete()
      .from(mission)
      .where("id = :id", { id: deleteMission.id })
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("DELETE", "mission", err);
      });
  }
}
